#!/bin/bash

EINCORRECT_USAGE=2

#function that computes time difference between current time
#and a date from a file passed as input with the following format
# "START TIME = %Y-%m-%d-%H:%M:%S". 
#eg : "START_TIME = 2014-09-22 14:20:21"
getTimeDiff()
{
    if [ "$#" -ne 1 ]; then 
        echo "Illegal number of parameters."
        echo "Usage: getTimeDiff \$input_file";
        return $EINCORRECT_USAGE
    fi
    local input_file=$1
    if [[ -f "${input_file}" ]]; then
        local start_date=`cat "${input_file}" | grep "START TIME" | awk -F'=' '{print $2 }'`
        local current_date=`date +"%F %H:%M:%S"`
        
        #compute time difference
        local diff_seconds=$(( ( $(date -d "${current_date}" +%s ) - $(date -d "${start_date}" +%s )) % 60 ))
        local diff_minutes=$(( $((( $(date -d "${current_date}" +%s ) - $(date -d "${start_date}" +%s )) / 60 )) % 60 ))
        local diff_hours=$(( $(( ( $(date -d "${current_date}" +%s ) - $(date -d "${start_date}" +%s )) / 60 / 60 )) % 24 ))
        local diff_days=$((( $(date -d "${current_date}" +%s ) - $(date -d "${start_date}" +%s )) / 60 / 60 /24 ))

        #output formatting
        if [[ "${diff_days}" -lt 1 ]]; then
            diff_days=""
            if [[ $diff_hours -lt 1 ]]; then diff_hours=""; fi
        fi

        if [[ -n "${diff_days}" ]]; then printf "%02d-" $diff_days; fi
        if [[ -n "${diff_hours}" ]]; then printf "%02d:" $diff_hours; fi
        printf "%02d:" $diff_minutes
        printf "%02d" $diff_seconds
        echo 
    fi
    return 0
} 
